@@ -3,7 +3,7 @@
 // RInside.cpp: R/C++ interface class library -- Easier R embedding into C++
 //
 // Copyright (C) 2009         Dirk Eddelbuettel
-// Copyright (C) 2010 - 2019  Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2022  Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of RInside.
 //
@@ -37,7 +37,7 @@ const char *programName = "RInside";
     extern int optind;
 
     #include <windef.h>
-    char rHome[MAX_PATH];
+    char rHome[MAX_PATH+1];
 #endif
 
 RInside::~RInside() {           // now empty as MemBuf is internal
@@ -62,10 +62,14 @@ RInside::RInside(): global_env_m(NULL)
 }
 
 #ifdef _WIN32
+#if R_VERSION >= R_Version(4,2,0)
+static int myReadConsole(const char *prompt, unsigned char *buf, int len, int addtohistory) {
+#else
 static int myReadConsole(const char *prompt, char *buf, int len, int addtohistory) {
+#endif
     fputs(prompt, stdout);
     fflush(stdout);
-    if (fgets(buf, len, stdin))
+    if (fgets((char *)buf, len, stdin))
         return 1;
     else
         return 0;
@@ -230,8 +234,8 @@ void RInside::init_tempdir(void) {
 void RInside::init_rand(void) { 		// code borrows from R's TimeToSeed() in datetime.c
     unsigned int pid = getpid();
     struct timeval tv;          		// this is ifdef'ed by R, we just assume we have it
-    gettimeofday (&tv, NULL);
-    unsigned int seed = ((uint64_t) tv.tv_usec << 16) ^ tv.tv_sec;
+    gettimeofday (&tv, NULL);           // we could borrow autoconf setup from littler to ensure
+    unsigned int seed = (unsigned int)(((uint_least64_t) tv.tv_usec << 16) ^ tv.tv_sec);
     seed ^= (pid << 16);         		// R 2.14.0 started to also use pid to support parallel
     srand(seed);
 }
@@ -421,9 +425,17 @@ RInside* RInside::instancePtr(){
     return instance_m;
 }
 
+extern "C" {
+     void run_Rmainloop(void);
+}
+ 
 void RInside::repl() {
-    R_ReplDLLinit();
-    while (R_ReplDLLdo1() > 0) {}
+    run_Rmainloop();
+
+    // Causes problems under Windows.
+    // For example, terminates after plot(0,0)
+    // R_ReplDLLinit();
+    // while (R_ReplDLLdo1() > 0) {}
 }
 
 /* callbacks */
